=== modified file '__init__.py'
--- __init__.py	2007-02-01 16:41:53 +0000
+++ __init__.py	2007-02-03 16:04:46 +0000
@@ -52,6 +52,10 @@
 
 check_bzrlib_version(version_info[:2])
 
+from bzrlib.trace import warning
+if __name__ != 'bzrlib.plugins.gtk':
+    warning("Not running as bzrlib.plugins.gtk, things may break.")
+
 from bzrlib import errors
 from bzrlib.commands import Command, register_command, display_command
 from bzrlib.errors import NotVersionedError, BzrCommandError, NoSuchFile
@@ -74,7 +78,7 @@
 
 def set_ui_factory():
     pygtk = import_pygtk()
-    from olive.ui import GtkUIFactory
+    from ui import GtkUIFactory
     import bzrlib.ui
     bzrlib.ui.ui_factory = GtkUIFactory()
 
@@ -92,7 +96,7 @@
             if str(e) == "could not open display":
                 raise NoDisplayError
 
-        from bzrlib.plugins.gtk.olive.branch import BranchDialog
+        from bzrlib.plugins.gtk.branch import BranchDialog
 
         set_ui_factory()
         dialog = BranchDialog(os.path.abspath('.'))
@@ -113,7 +117,7 @@
             if str(e) == "could not open display":
                 raise NoDisplayError
 
-        from bzrlib.plugins.gtk.olive.checkout import CheckoutDialog
+        from bzrlib.plugins.gtk.checkout import CheckoutDialog
 
         set_ui_factory()
         dialog = CheckoutDialog(os.path.abspath('.'))
@@ -137,7 +141,7 @@
             if str(e) == "could not open display":
                 raise NoDisplayError
 
-        from bzrlib.plugins.gtk.olive.push import PushDialog
+        from push import PushDialog
 
         set_ui_factory()
         dialog = PushDialog(branch)
@@ -172,10 +176,10 @@
             tree1 = wt
             tree2 = tree1.basis_tree()
 
-        from viz.diffwin import DiffWindow
+        from diff import DiffWindow
         import gtk
         window = DiffWindow()
-        window.connect("destroy", lambda w: gtk.main_quit())
+        window.connect("destroy", gtk.main_quit)
         window.set_diff("Working Tree", tree1, tree2)
         if filename is not None:
             tree_filename = wt.relpath(filename)
@@ -222,14 +226,17 @@
             else:
                 (revno, revid) = revision[0].in_history(branch)
 
-            from viz.bzrkapp import BzrkApp
+            from viz.branchwin import BranchWindow
+            import gtk
                 
-            app = BzrkApp()
-            app.show(branch, revid, limit)
+            pp = BranchWindow()
+            pp.set_branch(branch, revid, limit)
+            pp.connect("destroy", lambda w: gtk.main_quit())
+            pp.show()
+            gtk.main()
         finally:
             branch.repository.unlock()
             branch.unlock()
-        app.main()
 
 
 register_command(cmd_visualise)
@@ -309,6 +316,7 @@
 
     Graphical user interface for committing revisions"""
     
+    aliases = [ "gci" ]
     takes_args = []
     takes_options = []
 
@@ -323,7 +331,7 @@
                 raise NoDisplayError
 
         set_ui_factory()
-        from olive.commit import CommitDialog
+        from commit import CommitDialog
         from bzrlib.commit import Commit
         from bzrlib.errors import (BzrCommandError,
                                    NotBranchError,
@@ -352,6 +360,39 @@
 
 register_command(cmd_gcommit)
 
+class cmd_gstatus(Command):
+    """GTK+ status dialog
+
+    Graphical user interface for showing status 
+    information."""
+    
+    aliases = [ "gst" ]
+    takes_args = ['PATH?']
+    takes_options = []
+
+    def run(self, path='.'):
+        import os
+        pygtk = import_pygtk()
+
+        try:
+            import gtk
+        except RuntimeError, e:
+            if str(e) == "could not open display":
+                raise NoDisplayError
+
+        set_ui_factory()
+        from status import StatusDialog
+        (wt, wt_path) = WorkingTree.open_containing(path)
+        status = StatusDialog(wt, wt_path)
+        status.connect("destroy", gtk.main_quit)
+        status.run()
+
+register_command(cmd_gstatus)
+
+
+import gettext
+gettext.install('olive-gtk')
+
 class NoDisplayError(BzrCommandError):
     """gtk could not find a proper display"""
 
@@ -364,4 +405,3 @@
     result = TestSuite()
     result.addTest(tests.test_suite())
     return result
-

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2007-01-26 11:48:08 +0000
+++ annotate/gannotate.py	2007-02-03 14:17:40 +0000
@@ -28,8 +28,7 @@
 from bzrlib.revision import NULL_REVISION, CURRENT_REVISION
 
 from colormap import AnnotateColorMap, AnnotateColorSaturation
-from logview import LogView
-from spanselector import SpanSelector
+from bzrlib.plugins.gtk.logview import LogView
 
 
 (
@@ -244,7 +243,7 @@
                 tree2 = repository.revision_tree(revision.parent_ids[0])
             else:
                 tree2 = repository.revision_tree(NULL_REVISION)
-        from bzrlib.plugins.gtk.viz.diffwin import DiffWindow
+        from bzrlib.plugins.gtk.diff import DiffWindow
         window = DiffWindow()
         window.set_diff("Diff for row %d" % (row+1), tree1, tree2)
         window.set_file(tree1.id2path(self.file_id))
@@ -312,7 +311,6 @@
     def _create_log_view(self):
         lv = LogView()
         lv.show()
-
         return lv
 
     def _create_button_box(self):
@@ -378,6 +376,7 @@
         self.message = "?"
         self.timestamp = 0.0
         self.timezone = 0
+        self.properties = []
 
 
 class RevisionCache(object):

=== renamed file 'olive/branch.py' => 'branch.py'
--- olive/branch.py	2007-02-01 14:42:37 +0000
+++ branch.py	2007-02-03 15:04:56 +0000
@@ -24,7 +24,6 @@
 
 import gtk
 
-from olive import delimiter
 from errors import show_bzr_error
 
 from bzrlib.branch import Branch
@@ -33,6 +32,7 @@
 
 from dialog import error_dialog, info_dialog
 
+from history import UrlHistory
 
 class BranchDialog(gtk.Dialog):
     """ New implementation of the Branch dialog. """
@@ -101,30 +101,16 @@
         self.vbox.show_all()
         
         # Build branch history
+        self._history = UrlHistory(GlobalConfig(), 'branch_history')
         self._build_history()
     
     def _build_history(self):
         """ Build up the branch history. """
-        config = GlobalConfig()
-        history = config.get_user_option('gbranch_history')
-        if history is not None:
-            self._combo_model = gtk.ListStore(str)
-            for item in history.split(delimiter):
-                self._combo_model.append([ item ])
-            self._combo.set_model(self._combo_model)
-            self._combo.set_text_column(0)
-    
-    def _add_to_history(self, location):
-        """ Add specified location to the history (if not yet added). """
-        config = GlobalConfig()
-        history = config.get_user_option('gbranch_history')
-        if history is None:
-            config.set_user_option('gbranch_history', location)
-        else:
-            h = history.split(delimiter)
-            if location not in h:
-                h.append(location)
-            config.set_user_option('gbranch_history', delimiter.join(h))                
+        self._combo_model = gtk.ListStore(str)
+        for item in self._history.get_entries():
+            self._combo_model.append([ item ])
+        self._combo.set_model(self._combo_model)
+        self._combo.set_text_column(0)
     
     def _get_last_revno(self):
         """ Get the revno of the last revision (if any). """
@@ -205,7 +191,7 @@
         finally:
             br_from.unlock()
                 
-        self._add_to_history(location)
+        self._history.add_entry(location)
         info_dialog(_('Branching successful'),
                     _('%d revision(s) branched.') % revs)
         

=== added file 'bzr-icon-64.png'
Binary files bzr-icon-64.png and bzr-icon-64.png differ
=== renamed file 'olive/checkout.py' => 'checkout.py'
--- olive/checkout.py	2007-02-01 14:42:37 +0000
+++ checkout.py	2007-02-03 15:04:56 +0000
@@ -24,7 +24,6 @@
 
 import gtk
 
-from olive import delimiter
 from errors import show_bzr_error
 
 from bzrlib.branch import Branch
@@ -32,6 +31,7 @@
 
 from dialog import error_dialog
 
+from history import UrlHistory
 
 class CheckoutDialog(gtk.Dialog):
     """ New implementation of the Checkout dialog. """
@@ -103,30 +103,16 @@
         self.vbox.show_all()
         
         # Build checkout history
+        self._history = UrlHistory(GlobalConfig(), 'branch_history')
         self._build_history()
     
     def _build_history(self):
         """ Build up the checkout history. """
-        config = GlobalConfig()
-        history = config.get_user_option('gcheckout_history')
-        if history is not None:
-            self._combo_model = gtk.ListStore(str)
-            for item in history.split(delimiter):
-                self._combo_model.append([ item ])
-            self._combo.set_model(self._combo_model)
-            self._combo.set_text_column(0)
-    
-    def _add_to_history(self, location):
-        """ Add specified location to the history (if not yet added). """
-        config = GlobalConfig()
-        history = config.get_user_option('gcheckout_history')
-        if history is None:
-            config.set_user_option('gcheckout_history', location)
-        else:
-            h = history.split(delimiter)
-            if location not in h:
-                h.append(location)
-            config.set_user_option('gcheckout_history', delimiter.join(h))                
+        self._combo_model = gtk.ListStore(str)
+        for item in self._history.get_entries():
+            self._combo_model.append([ item ])
+        self._combo.set_model(self._combo_model)
+        self._combo.set_text_column(0)
     
     def _get_last_revno(self):
         """ Get the revno of the last revision (if any). """
@@ -189,7 +175,7 @@
         
         br_from.create_checkout(to_location, revision_id, lightweight)
         
-        self._add_to_history(location)
+        self._history.add_entry(location)
         
         self.response(gtk.RESPONSE_OK)
     

=== renamed file 'olive/commit.py' => 'commit.py'
--- olive/commit.py	2007-01-30 11:33:28 +0000
+++ commit.py	2007-02-03 14:19:44 +0000
@@ -21,7 +21,6 @@
     pass
 
 import gtk
-import gtk.glade
 import gobject
 import pango
 
@@ -32,7 +31,6 @@
 
 from dialog import error_dialog, question_dialog
 from errors import show_bzr_error
-from guifiles import GLADEFILENAME
 
 class CommitDialog(gtk.Dialog):
     """ New implementation of the Commit dialog. """
@@ -82,17 +80,17 @@
         # Create the widgets
         self._button_commit = gtk.Button(_("Comm_it"), use_underline=True)
         if self._is_checkout:
-            self._check_local = gtk.CheckButton(_("_Local only commit (works in checkouts)"),
+            self._check_local = gtk.CheckButton(_("_Only commit locally"),
                                                 use_underline=True)
-        self._check_strict = gtk.CheckButton(_("_Strict commit (fails if unknown files are present)"),
+        self._check_strict = gtk.CheckButton(_("_Allow unknown files"),
                                              use_underline=True)
-        self._expander_files = gtk.Expander(_("Please select the file(s) to commit"))
+        self._expander_files = gtk.Expander(_("File(s) to commit"))
         self._vpaned_main = gtk.VPaned()
         self._scrolledwindow_files = gtk.ScrolledWindow()
         self._scrolledwindow_message = gtk.ScrolledWindow()
         self._treeview_files = gtk.TreeView()
         self._vbox_message = gtk.VBox()
-        self._label_message = gtk.Label(_("Please specify a commit message:"))
+        self._label_message = gtk.Label(_("Commit message:"))
         self._textview_message = gtk.TextView()
         
         if self._is_pending:
@@ -166,7 +164,7 @@
         (model, iter) = treeselection.get_selected()
         
         if iter is not None:
-            from olive import DiffWindow
+            from diff import DiffWindow
             
             _selected = model.get_value(iter, 1)
             

=== renamed file 'olive/dialog.py' => 'dialog.py'
--- olive/dialog.py	2007-01-31 10:00:12 +0000
+++ dialog.py	2007-02-03 14:18:57 +0000
@@ -46,55 +46,33 @@
     # Destroy the dialog
     dialog.destroy()
 
-def _message_dialog(type, primary, secondary):
+def _message_dialog(type, primary, secondary, buttons=gtk.BUTTONS_OK):
     """ Display a given type of MessageDialog with the given message.
     
-    :param type: error | warning | info
+    :param type: message dialog type
     
     :param message: the message you want to display.
     """
-    if type == 'error':
-        dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                   type=gtk.MESSAGE_ERROR,
-                                   buttons=gtk.BUTTONS_OK)
-        dialog.set_markup('<big><b>' + primary + '</b></big>')
-    elif type == 'warning':
-        dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                   type=gtk.MESSAGE_WARNING,
-                                   buttons=gtk.BUTTONS_OK)
-        dialog.set_markup('<big><b>' + primary + '</b></big>')
-    elif type == 'info':
-        dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                   type=gtk.MESSAGE_INFO,
-                                   buttons=gtk.BUTTONS_OK)
-        dialog.set_markup('<big><b>' + primary + '</b></big>')
-    elif type == 'question':
-        dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                   type=gtk.MESSAGE_QUESTION,
-                                   buttons=gtk.BUTTONS_YES_NO)
-        dialog.set_markup('<big><b>' + primary + '</b></big>')
-    else:
-        return
-
+    dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL, type=type,
+                               buttons=buttons)
+    dialog.set_markup('<big><b>' + primary + '</b></big>')
     dialog.format_secondary_markup(secondary)
-
     response = dialog.run()
     dialog.destroy()
-
     return response
 
 def error_dialog(primary, secondary):
     """ Display an error dialog with the given message. """
-    return _message_dialog('error', primary, secondary)
+    return _message_dialog(gtk.MESSAGE_ERROR, primary, secondary)
 
 def info_dialog(primary, secondary):
     """ Display an info dialog with the given message. """
-    return _message_dialog('info', primary, secondary)
+    return _message_dialog(gtk.MESSAGE_INFO, primary, secondary)
 
 def warning_dialog(primary, secondary):
     """ Display a warning dialog with the given message. """
-    return _message_dialog('warning', primary, secondary)
+    return _message_dialog(gtk.MESSAGE_WARNING, primary, secondary)
 
 def question_dialog(primary, secondary):
     """ Display a dialog with the given question. """
-    return _message_dialog('question', primary, secondary)
+    return _message_dialog(gtk.MESSAGE_QUESTION, primary, secondary, gtk.BUTTONS_YES_NO)

=== renamed file 'viz/diffwin.py' => 'diff.py'
=== renamed file 'olive/errors.py' => 'errors.py'
--- olive/errors.py	2007-01-31 23:52:50 +0000
+++ errors.py	2007-02-03 14:19:44 +0000
@@ -15,7 +15,6 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import bzrlib.errors as errors
-
 from dialog import error_dialog
 
 def show_bzr_error(unbound):

=== added file 'history.py'
--- history.py	1970-01-01 00:00:00 +0000
+++ history.py	2007-02-03 15:04:56 +0000
@@ -0,0 +1,32 @@
+# Copyright (C) 2007 Jelmer Vernooij <jelmer@samba.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+delimiter = " "
+
+class UrlHistory:
+    def __init__(self, config, name):
+        self._config = config
+        self._name = name
+
+    def add_entry(self, url):
+        self._config.set_user_option(self._name, delimiter.join(self.get_entries() + [url]))
+
+    def get_entries(self):
+        history = self._config.get_user_option(self._name)
+        if history is None:
+            return []
+        else:
+            return history.split(delimiter)

=== renamed file 'annotate/logview.py' => 'logview.py'
--- annotate/logview.py	2006-05-19 16:56:46 +0000
+++ logview.py	2007-02-03 12:41:33 +0000
@@ -31,59 +31,89 @@
 
     def __init__(self, revision=None):
         gtk.ScrolledWindow.__init__(self)
-        self.parent_id_widgets = []
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.set_shadow_type(gtk.SHADOW_NONE)
         self._create()
+        self._show_callback = None
+        self._go_callback = None
+        self._clicked_callback = None
 
         if revision is not None:
             self.set_revision(revision)
 
+    def set_show_callback(self, callback):
+        self._show_callback = callback
+
+    def set_go_callback(self, callback):
+        self._go_callback = callback
+
     def set_revision(self, revision):
+        self._revision = revision
         self.revision_id.set_text(revision.revision_id)
         self.committer.set_text(revision.committer)
         self.timestamp.set_text(format_date(revision.timestamp,
                                             revision.timezone))
         self.message_buffer.set_text(revision.message)
+        try:
+            self.branchnick_label.set_text(revision.properties['branch-nick'])
+        except KeyError:
+            self.branchnick_label.set_text("")
+
         self._add_parents(revision.parent_ids)
 
+    def _show_clicked_cb(self, widget, revid, parentid):
+        """Callback for when the show button for a parent is clicked."""
+        self._show_callback(revid, parentid)
+
+    def _go_clicked_cb(self, widget, revid):
+        """Callback for when the go button for a parent is clicked."""
+        self._go_callback(revid)
+
     def _add_parents(self, parent_ids):
-        for widget in self.parent_id_widgets:
-            self.table.remove(widget)
+        for widget in self.parents_widgets:
+            self.parents_table.remove(widget)
             
-        self.parent_id_widgets = []
-
-        if len(parent_ids):
-            self.table.resize(4 + len(parent_ids), 2)
-
-            align = gtk.Alignment(1.0, 0.5)
+        self.parents_widgets = []
+        self.parents_table.resize(max(len(parent_ids), 1), 2)
+
+        for idx, parent_id in enumerate(parent_ids):
+            align = gtk.Alignment(0.0, 0.0)
+            self.parents_widgets.append(align)
+            self.parents_table.attach(align, 1, 2, idx, idx + 1,
+                                      gtk.EXPAND | gtk.FILL, gtk.FILL)
             align.show()
-            self.table.attach(align, 0, 1, 3, 4, gtk.FILL, gtk.FILL)
-            self.parent_id_widgets.append(align)
-
-            label = gtk.Label()
-            if len(parent_ids) > 1:
-                label.set_markup("<b>Parent Ids:</b>")
+
+            hbox = gtk.HBox(False, spacing=6)
+            align.add(hbox)
+            hbox.show()
+
+            image = gtk.Image()
+            image.set_from_stock(
+                gtk.STOCK_FIND, gtk.ICON_SIZE_SMALL_TOOLBAR)
+            image.show()
+
+            if self._show_callback is not None:
+                button = gtk.Button()
+                button.add(image)
+                button.connect("clicked", self._show_clicked_cb,
+                               self._revision.revision_id, parent_id)
+                hbox.pack_start(button, expand=False, fill=True)
+                button.show()
+
+            if self._go_callback is not None:
+                button = gtk.Button(parent_id)
+                button.connect("clicked", self._go_clicked_cb, parent_id)
             else:
-                label.set_markup("<b>Parent Id:</b>")
-            label.show()
-            align.add(label)
-
-            for i, parent_id in enumerate(parent_ids):
-                align = gtk.Alignment(0.0, 0.5)
-                self.parent_id_widgets.append(align)
-                self.table.attach(align, 1, 2, i + 3, i + 4,
-                                  gtk.EXPAND | gtk.FILL, gtk.FILL)
-                align.show()
-                label = gtk.Label(parent_id)
-                label.set_selectable(True)
-                label.show()
-                align.add(label)
+                button = gtk.Label(parent_id)
+            button.set_use_underline(False)
+            hbox.pack_start(button, expand=False, fill=True)
+            button.show()
 
     def _create(self):
         vbox = gtk.VBox(False, 6)
         vbox.set_border_width(6)
         vbox.pack_start(self._create_headers(), expand=False, fill=True)
+        vbox.pack_start(self._create_parents_table(), expand=False, fill=True)
         vbox.pack_start(self._create_message_view())
         self.add_with_viewport(vbox)
         vbox.show()
@@ -93,12 +123,28 @@
         self.table.set_row_spacings(6)
         self.table.set_col_spacings(6)
         self.table.show()
-        
+
+        align = gtk.Alignment(1.0, 0.5)
+        label = gtk.Label()
+        label.set_markup("<b>Revision Id:</b>")
+        align.add(label)
+        self.table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
+        align.show()
+        label.show()
+
+        align = gtk.Alignment(0.0, 0.5)
+        self.revision_id = gtk.Label()
+        self.revision_id.set_selectable(True)
+        align.add(self.revision_id)
+        self.table.attach(align, 1, 2, 0, 1, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        align.show()
+        self.revision_id.show()
+
         align = gtk.Alignment(1.0, 0.5)
         label = gtk.Label()
         label.set_markup("<b>Committer:</b>")
         align.add(label)
-        self.table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
+        self.table.attach(align, 0, 1, 1, 2, gtk.FILL, gtk.FILL)
         align.show()
         label.show()
 
@@ -106,15 +152,31 @@
         self.committer = gtk.Label()
         self.committer.set_selectable(True)
         align.add(self.committer)
-        self.table.attach(align, 1, 2, 0, 1, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        self.table.attach(align, 1, 2, 1, 2, gtk.EXPAND | gtk.FILL, gtk.FILL)
         align.show()
         self.committer.show()
 
+        align = gtk.Alignment(0.0, 0.5)
+        label = gtk.Label()
+        label.set_markup("<b>Branch nick:</b>")
+        align.add(label)
+        self.table.attach(align, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
+        label.show()
+        align.show()
+
+        align = gtk.Alignment(0.0, 0.5)
+        self.branchnick_label = gtk.Label()
+        self.branchnick_label.set_selectable(True)
+        align.add(self.branchnick_label)
+        self.table.attach(align, 1, 2, 2, 3, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        self.branchnick_label.show()
+        align.show()
+
         align = gtk.Alignment(1.0, 0.5)
         label = gtk.Label()
         label.set_markup("<b>Timestamp:</b>")
         align.add(label)
-        self.table.attach(align, 0, 1, 1, 2, gtk.FILL, gtk.FILL)
+        self.table.attach(align, 0, 1, 3, 4, gtk.FILL, gtk.FILL)
         align.show()
         label.show()
 
@@ -122,28 +184,29 @@
         self.timestamp = gtk.Label()
         self.timestamp.set_selectable(True)
         align.add(self.timestamp)
-        self.table.attach(align, 1, 2, 1, 2, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        self.table.attach(align, 1, 2, 3, 4, gtk.EXPAND | gtk.FILL, gtk.FILL)
         align.show()
         self.timestamp.show()
 
-        align = gtk.Alignment(1.0, 0.5)
-        label = gtk.Label()
-        label.set_markup("<b>Revision Id:</b>")
-        align.add(label)
-        self.table.attach(align, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
-        align.show()
-        label.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        self.revision_id = gtk.Label()
-        self.revision_id.set_selectable(True)
-        align.add(self.revision_id)
-        self.table.attach(align, 1, 2, 2, 3, gtk.EXPAND | gtk.FILL, gtk.FILL)
-        align.show()
-        self.revision_id.show()
-
         return self.table
 
+    def _create_parents_table(self):
+        self.parents_table = gtk.Table(rows=1, columns=2)
+        self.parents_table.set_row_spacings(3)
+        self.parents_table.set_col_spacings(6)
+        self.parents_table.show()
+        self.parents_widgets = []
+
+        label = gtk.Label()
+        label.set_markup("<b>Parents:</b>")
+        align = gtk.Alignment(0.0, 0.5)
+        align.add(label)
+        self.parents_table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
+        label.show()
+        align.show()
+
+        return self.parents_table
+
     def _create_message_view(self):
         self.message_buffer = gtk.TextBuffer()
         tv = gtk.TextView(self.message_buffer)

=== renamed file 'olive/merge.py' => 'merge.py'
--- olive/merge.py	2007-01-29 23:27:09 +0000
+++ merge.py	2007-02-03 14:19:44 +0000
@@ -30,7 +30,7 @@
 
 from dialog import error_dialog, info_dialog, warning_dialog
 from errors import show_bzr_error
-from guifiles import GLADEFILENAME
+from olive.guifiles import GLADEFILENAME
 
 
 class MergeDialog:

=== modified file 'nautilus-bzr.py'
--- nautilus-bzr.py	2006-10-15 20:15:05 +0000
+++ nautilus-bzr.py	2007-02-03 13:01:12 +0000
@@ -70,7 +70,7 @@
         except NotBranchError:
             return
 
-        from bzrlib.plugins.gtk.viz.diffwin import DiffWindow
+        from bzrlib.plugins.gtk.viz.diff import DiffWindow
         window = DiffWindow()
         window.set_diff(tree.branch.nick, tree, tree.branch.basis_tree())
         window.show()
@@ -118,7 +118,7 @@
         if vfs_file.get_uri_scheme() != 'file':
             return
 
-        from bzrlib.plugins.gtk.olive.branch import BranchDialog
+        from bzrlib.plugins.gtk.branch import BranchDialog
         
         dialog = BranchDialog(vfs_file.get_name())
         dialog.display()
@@ -134,7 +134,7 @@
         except NotBranchError:
             return
 
-        from bzrlib.plugins.gtk.olive.commit import CommitDialog
+        from bzrlib.plugins.gtk.commit import CommitDialog
         dialog = CommitDialog(tree, path)
         dialog.display()
         gtk.main()
@@ -170,7 +170,7 @@
         except NotBranchError:
             return
 
-        from bzrlib.plugins.gtk.olive.pull import PullDialog
+        from bzrlib.plugins.gtk.pull import PullDialog
         dialog = PullDialog(tree, path)
         dialog.display()
         gtk.main()
@@ -188,7 +188,7 @@
         except NotBranchError:
             return
 
-        from bzrlib.plugins.gtk.olive.merge import MergeDialog
+        from bzrlib.plugins.gtk.merge import MergeDialog
         dialog = MergeDialog(tree, path)
         dialog.display()
         gtk.main()

=== modified file 'olive-gtk'
--- olive-gtk	2006-10-26 13:16:07 +0000
+++ olive-gtk	2007-02-03 15:24:48 +0000
@@ -78,14 +78,13 @@
             print >>sys.stderr, "Can't find bzrlib location"
             sys.exit(1)
 
-
-from olive import OliveGtk
 from bzrlib.plugin import load_plugins
 load_plugins()
 
 import bzrlib.ui
-import olive.ui
-bzrlib.ui.ui_factory = olive.ui.GtkUIFactory()
+import ui
+bzrlib.ui.ui_factory = ui.GtkUIFactory()
 
+from olive import OliveGtk
 app = OliveGtk()
 gtk.main()

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2007-02-01 14:41:43 +0000
+++ olive/__init__.py	2007-02-03 16:03:23 +0000
@@ -35,28 +35,16 @@
 import bzrlib.errors as bzrerrors
 from bzrlib.workingtree import WorkingTree
 
-from dialog import error_dialog, info_dialog, warning_dialog
-from errors import show_bzr_error
+from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, warning_dialog
+from bzrlib.plugins.gtk.errors import show_bzr_error
 from guifiles import GLADEFILENAME
 
-# import this classes only once
-try:
-    from bzrlib.plugins.gtk.viz.diffwin import DiffWindow
-    from bzrlib.plugins.gtk.viz.branchwin import BranchWindow
-    from bzrlib.plugins.gtk.annotate.gannotate import GAnnotateWindow
-    from bzrlib.plugins.gtk.annotate.config import GAnnotateConfig
-except ImportError:
-    # olive+bzr-gtk not installed. try to import from sources
-    path = os.path.dirname(os.path.dirname(__file__))
-    if path not in sys.path:
-        sys.path.append(path)
-    from viz.diffwin import DiffWindow
-    from viz.branchwin import BranchWindow
-    from annotate.gannotate import GAnnotateWindow
-    from annotate.config import GAnnotateConfig
-
-# History delimiter used in config files
-delimiter = ' '
+from bzrlib.plugins.gtk.diff import DiffWindow
+from bzrlib.plugins.gtk.viz.branchwin import BranchWindow
+from bzrlib.plugins.gtk.annotate.gannotate import GAnnotateWindow
+from bzrlib.plugins.gtk.annotate.config import GAnnotateConfig
+from bzrlib.plugins.gtk.commit import CommitDialog
+from bzrlib.plugins.gtk.push import PushDialog
 
 class OliveGtk:
     """ The main Olive GTK frontend class. This is called when launching the
@@ -64,11 +52,8 @@
     
     def __init__(self):
         self.toplevel = gtk.glade.XML(GLADEFILENAME, 'window_main', 'olive-gtk')
-        
         self.window = self.toplevel.get_widget('window_main')
-        
-        self.pref = OlivePreferences()
-        
+        self.pref = Preferences()
         self.path = None
 
         # Initialize the statusbar
@@ -211,7 +196,7 @@
         return self.path
    
     def on_about_activate(self, widget):
-        from dialog import about
+        from bzrlib.plugins.gtk.dialog import about
         about()
         
     def on_menuitem_add_files_activate(self, widget):
@@ -222,7 +207,7 @@
     
     def on_menuitem_branch_get_activate(self, widget):
         """ Branch/Get... menu handler. """
-        from branch import BranchDialog
+        from bzrlib.plugins.gtk.branch import BranchDialog
         branch = BranchDialog(self.get_path(), self.window)
         response = branch.run()
         if response != gtk.RESPONSE_NONE:
@@ -235,7 +220,7 @@
     
     def on_menuitem_branch_checkout_activate(self, widget):
         """ Branch/Checkout... menu handler. """
-        from checkout import CheckoutDialog
+        from bzrlib.plugins.gtk.checkout import CheckoutDialog
         checkout = CheckoutDialog(self.get_path(), self.window)
         response = checkout.run()
         if response != gtk.RESPONSE_NONE:
@@ -246,9 +231,9 @@
             
             checkout.destroy()
     
+    @show_bzr_error
     def on_menuitem_branch_commit_activate(self, widget):
         """ Branch/Commit... menu handler. """
-        from commit import CommitDialog
         commit = CommitDialog(self.wt, self.wtpath, self.notbranch, self.get_selected_right(), self.window)
         response = commit.run()
         if response != gtk.RESPONSE_NONE:
@@ -261,7 +246,7 @@
     
     def on_menuitem_branch_merge_activate(self, widget):
         """ Branch/Merge... menu handler. """
-        from merge import MergeDialog
+        from bzrlib.plugins.gtk.merge import MergeDialog
         
         if self.check_for_changes():
             error_dialog(_('There are local changes in the branch'),
@@ -270,6 +255,7 @@
             merge = MergeDialog(self.wt, self.wtpath)
             merge.display()
 
+    @show_bzr_error
     def on_menuitem_branch_missing_revisions_activate(self, widget):
         """ Branch/Missing revisions menu handler. """
         local_branch = self.wt.branch
@@ -321,7 +307,6 @@
     
     def on_menuitem_branch_push_activate(self, widget):
         """ Branch/Push... menu handler. """
-        from push import PushDialog
         push = PushDialog(self.wt.branch, self.window)
         response = push.run()
         if response != gtk.RESPONSE_NONE:
@@ -341,8 +326,8 @@
     
     def on_menuitem_branch_status_activate(self, widget):
         """ Branch/Status... menu handler. """
-        from status import OliveStatus
-        status = OliveStatus(self.wt, self.wtpath)
+        from bzrlib.plugins.gtk.status import StatusDialog
+        status = StatusDialog(self.wt, self.wtpath)
         status.display()
     
     @show_bzr_error
@@ -930,7 +915,7 @@
 
 import ConfigParser
 
-class OlivePreferences:
+class Preferences:
     """ A class which handles Olive's preferences. """
     def __init__(self):
         """ Initialize the Preferences class. """
@@ -1014,6 +999,8 @@
     
     def set_bookmark_title(self, path, title):
         """ Set bookmark title. """
+        # FIXME: What if path isn't listed yet?
+        # FIXME: Canonicalize paths first?
         self.config.set(path, 'title', title)
     
     def remove_bookmark(self, path):

=== modified file 'olive/add.py'
--- olive/add.py	2006-10-25 16:29:18 +0000
+++ olive/add.py	2007-02-03 14:18:57 +0000
@@ -28,7 +28,7 @@
 import bzrlib.add
 import bzrlib.errors as errors
 
-from dialog import error_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
 
 

=== modified file 'olive/bookmark.py'
--- olive/bookmark.py	2007-02-01 14:52:43 +0000
+++ olive/bookmark.py	2007-02-03 14:18:57 +0000
@@ -22,8 +22,8 @@
 
 import gtk
 
-from olive import OlivePreferences
-from dialog import error_dialog
+from olive import Preferences
+from bzrlib.plugins.gtk.dialog import error_dialog
 
 
 class BookmarkDialog(gtk.Dialog):
@@ -36,7 +36,7 @@
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
         
-        self.pref = OlivePreferences()
+        self.pref = Preferences()
         
         # Get arguments
         self.selected = selected

=== modified file 'olive/info.py'
--- olive/info.py	2006-10-25 16:29:18 +0000
+++ olive/info.py	2007-02-03 14:18:57 +0000
@@ -25,7 +25,7 @@
 
 import bzrlib.errors as errors
 
-from dialog import error_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
 
 

=== modified file 'olive/menu.py'
--- olive/menu.py	2007-02-01 14:52:43 +0000
+++ olive/menu.py	2007-02-03 14:18:57 +0000
@@ -28,10 +28,10 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
-from dialog import error_dialog, info_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, warning_dialog
 from errors import show_bzr_error
 from launch import launch
-from olive import OlivePreferences, DiffWindow
+from olive import Preferences, DiffWindow
 
 class OliveMenu:
     """ This class is responsible for building the context menus. """
@@ -42,7 +42,7 @@
         self.uifile = UIFILENAME
 
         # Preferences handler
-        self.pref = OlivePreferences()
+        self.pref = Preferences()
         
         # Set default values
         self.path = path

=== modified file 'olive/mkdir.py'
--- olive/mkdir.py	2007-01-29 23:27:09 +0000
+++ olive/mkdir.py	2007-02-03 15:24:48 +0000
@@ -27,9 +27,11 @@
 
 import bzrlib.errors as errors
 
-from dialog import error_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog, warning_dialog
 from guifiles import GLADEFILENAME
 
+from bzrlib.plugins.gtk.errors import show_bzr_error
+
 
 class OliveMkdir:
     """ Display the Make directory dialog and perform the needed actions. """

=== modified file 'olive/move.py'
--- olive/move.py	2007-01-29 23:27:09 +0000
+++ olive/move.py	2007-02-03 14:18:57 +0000
@@ -29,7 +29,7 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
-from dialog import error_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog
 from errors import show_bzr_error
 from guifiles import GLADEFILENAME
 

=== modified file 'olive/remove.py'
--- olive/remove.py	2007-01-29 23:27:09 +0000
+++ olive/remove.py	2007-02-03 14:18:57 +0000
@@ -27,7 +27,7 @@
 
 import bzrlib.errors as errors
 
-from dialog import error_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog, warning_dialog
 from guifiles import GLADEFILENAME
 
 

=== modified file 'olive/rename.py'
--- olive/rename.py	2007-01-29 23:27:09 +0000
+++ olive/rename.py	2007-02-03 14:18:57 +0000
@@ -28,7 +28,7 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
-from dialog import error_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
 
 

=== renamed file 'olive/push.py' => 'push.py'
--- olive/push.py	2007-02-01 14:41:43 +0000
+++ push.py	2007-02-03 15:04:56 +0000
@@ -22,7 +22,6 @@
     
 import gtk
 
-from olive import delimiter
 from errors import show_bzr_error
 
 from bzrlib.config import LocationConfig
@@ -30,6 +29,7 @@
 
 from dialog import error_dialog, info_dialog, question_dialog
 
+from history import UrlHistory
 
 class PushDialog(gtk.Dialog):
     """ New implementation of the Push dialog. """
@@ -88,35 +88,21 @@
         self.vbox.show_all()
         
         # Build location history
+        self._history = UrlHistory(self.branch.get_config(), 'push_history')
         self._build_history()
         
     def _build_history(self):
         """ Build up the location history. """
-        config = LocationConfig(self.branch.base)
-        history = config.get_user_option('gpush_history')
-        if history is not None:
-            self._combo_model = gtk.ListStore(str)
-            for item in history.split(delimiter):
-                self._combo_model.append([ item ])
-            self._combo.set_model(self._combo_model)
-            self._combo.set_text_column(0)
+        self._combo_model = gtk.ListStore(str)
+        for item in self._history.get_entries():
+            self._combo_model.append([ item ])
+        self._combo.set_model(self._combo_model)
+        self._combo.set_text_column(0)
         
         location = self.branch.get_push_location()
         if location:
             self._combo.get_child().set_text(location)
     
-    def _add_to_history(self, location):
-        """ Add specified location to the history (if not yet added). """
-        config = LocationConfig(self.branch.base)
-        history = config.get_user_option('gpush_history')
-        if history is None:
-            config.set_user_option('gpush_history', location)
-        else:
-            h = history.split(delimiter)
-            if location not in h:
-                h.append(location)
-            config.set_user_option('gpush_history', delimiter.join(h))
-    
     def _on_test_clicked(self, widget):
         """ Test button clicked handler. """
         import re
@@ -158,7 +144,7 @@
                 revs = do_push(self.branch, overwrite=True)
             return
         
-        self._add_to_history(location)
+        self._history.add_entry(location)
         info_dialog(_('Push successful'),
                     _("%d revision(s) pushed.") % revs)
         

=== renamed file 'olive/revbrowser.py' => 'revbrowser.py'
--- olive/revbrowser.py	2007-02-01 09:42:15 +0000
+++ revbrowser.py	2007-02-03 11:52:13 +0000
@@ -22,7 +22,6 @@
 
 import gobject
 import gtk
-import gtk.glade
 
 from bzrlib.osutils import format_date
 

=== renamed file 'olive/status.py' => 'status.py'
--- olive/status.py	2006-10-25 16:29:18 +0000
+++ status.py	2007-02-03 17:01:18 +0000
@@ -21,43 +21,47 @@
     pass
 
 import gtk
-import gtk.glade
-
-from guifiles import GLADEFILENAME
-
-
-class OliveStatus:
+
+class StatusDialog(gtk.MessageDialog):
     """ Display Status window and perform the needed actions. """
     def __init__(self, wt, wtpath):
         """ Initialize the Status window. """
-        self.glade = gtk.glade.XML(GLADEFILENAME, 'window_status')
-        
-        # Get the Status window widget
-        self.window = self.glade.get_widget('window_status')
-        
+        super(StatusDialog, self).__init__(flags=gtk.DIALOG_MODAL, buttons=gtk.BUTTONS_OK)
+        self.set_title("Working tree changes")
+        self.set_image(gtk.Label("Working tree status"))
+        self._create()
         self.wt = wt
         self.wtpath = wtpath
-        
-        # Check if current location is a branch
-        file_id = self.wt.path2id(wtpath)
-
         # Set the old working tree
         self.old_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
-        
-        # Dictionary for signal_autoconnect
-        dic = { "on_button_status_close_clicked": self.close }
-        
-        # Connect the signals to the handlers
-        self.glade.signal_autoconnect(dic)
-        
         # Generate status output
         self._generate_status()
 
+    def _create(self):
+        self.set_default_size(400, 300)
+        scrolledwindow = gtk.ScrolledWindow()
+        scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.treeview = gtk.TreeView()
+        scrolledwindow.add(self.treeview)
+        self.vbox.pack_start(scrolledwindow, True, True)
+        self.vbox.show_all()
+
+    def row_diff(self, tv, path, tvc):
+        file = self.model[path][1]
+        if file is None:
+            return
+        from bzrlib.plugins.gtk.diff import DiffWindow
+        window = DiffWindow()
+        window.set_diff("Working tree changes", self.old_tree, self.wt)
+        window.set_file(file)
+        window.show()
+
     def _generate_status(self):
         """ Generate 'bzr status' output. """
         self.model = gtk.TreeStore(str, str)
-        self.treeview = self.glade.get_widget('treeview_status')
+        self.treeview.set_headers_visible(False)
         self.treeview.set_model(self.model)
+        self.treeview.connect("row-activated", self.row_diff)
         
         cell = gtk.CellRendererText()
         cell.set_property("width-chars", 20)

=== modified file 'tests/__init__.py'
--- tests/__init__.py	2007-02-01 15:50:40 +0000
+++ tests/__init__.py	2007-02-03 15:04:56 +0000
@@ -15,10 +15,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from unittest import TestLoader, TestSuite
+from bzrlib.tests import TestUtil
+
 
 def test_suite():
     result = TestSuite()
 
-    loader = TestLoader()
+    loader = TestUtil.TestLoader()
+
+    testmod_names = ['test_preferences', 'test_history']
+    result.addTest(loader.loadTestsFromModuleNames(["%s.%s" % (__name__, i) for i in testmod_names]))
     return result
 

=== added file 'tests/test_history.py'
--- tests/test_history.py	1970-01-01 00:00:00 +0000
+++ tests/test_history.py	2007-02-03 15:04:56 +0000
@@ -0,0 +1,42 @@
+# Copyright (C) 2007 Jelmer Venrooij <jelmer@samba.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from bzrlib.tests import TestCaseInTempDir
+from bzrlib.plugins.gtk.history import UrlHistory
+
+from bzrlib import config
+
+class TestsUrlHistory(TestCaseInTempDir):
+    def setUp(self):
+        super(TestsUrlHistory, self).setUp()
+        self.config = config.GlobalConfig()
+
+    def test_add_entry(self):
+        """Tests whether a URL can be added to the history list.
+        The history store should only store the url, not try to
+        access it."""
+        self.history = UrlHistory(self.config, 'test_add_entry')
+        self.history.add_entry("http://foobarbla")
+
+    def test_get_entries(self):
+        self.history = UrlHistory(self.config, 'test_get_entries')
+        self.history.add_entry("http://foobar")
+        self.history.add_entry("file://bla")
+        self.assertEqual(["http://foobar", "file://bla"], self.history.get_entries())
+
+    def test_get_empty(self):
+        self.history = UrlHistory(self.config, 'test_get_empty')
+        self.assertEqual([], self.history.get_entries())

=== added file 'tests/test_preferences.py'
--- tests/test_preferences.py	1970-01-01 00:00:00 +0000
+++ tests/test_preferences.py	2007-02-03 10:45:37 +0000
@@ -0,0 +1,96 @@
+# Copyright (C) 2007 Jelmer Venrooij <jelmer@samba.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from bzrlib.tests import TestCase
+from bzrlib.plugins.gtk.olive import Preferences
+
+# FIXME: need to make sure that this also tests writing/reading.
+class TestPreferences(TestCase):
+    def test_create(self):
+        Preferences()
+
+    def test_add_bookmark(self):
+        """make sure a bookmark can be added. This function is only supposed 
+        to store the location, not try to access it. """
+        x = Preferences()
+        self.assertTrue(x.add_bookmark("file://foobar"))
+        self.assertTrue("file://foobar" in x.get_bookmarks())
+
+    def test_add_bookmark_twice(self):
+        """Adding an already present bookmark will result in False being 
+        returned."""
+        x = Preferences()
+        self.assertTrue(x.add_bookmark("file://foobar"))
+        self.assertFalse(x.add_bookmark("file://foobar"))
+
+    def test_set_bookmark_title(self):
+        """Test setting a title for an existing bookmark."""
+        x = Preferences()
+        x.add_bookmark("file://foobar")
+        x.set_bookmark_title("file://foobar", "My Bookmark")
+
+    def test_remove_bookmark(self):
+        """Test removing a bookmark."""
+        x = Preferences()
+        x.add_bookmark("http://example.com/branch")
+        x.remove_bookmark("http://example.com/branch")
+        self.assertFalse("http://example.com/branch" in x.get_bookmarks())
+
+    def test_get_bookmarks_empty(self):
+        """Test whether a new Preferences() object has an empty bookmarks 
+        list."""
+        x = Preferences()
+        self.assertEqual([], x.get_bookmarks())
+
+    def test_get_bookmark_title_set(self):
+        """Test getting a title for an existing bookmark."""
+        x = Preferences()
+        x.add_bookmark("file://foobar")
+        x.set_bookmark_title("file://foobar", "My Bookmark")
+        self.assertEqual("My Bookmark", x.get_bookmark_title("file://foobar"))
+
+    def test_get_bookmark_title_implicit(self):
+        """Test getting a bookmark title for a bookmark that doesn't
+        have a title set."""
+        x = Preferences()
+        x.add_bookmark("file://bla")
+        self.assertEqual("file://bla", x.get_bookmark_title("file://bla"))
+
+    def test_set_preference(self):
+        """Check whether setting preferences works."""
+        x = Preferences()
+        x.set_preference("foo", True)
+        x.set_preference("foo", False)
+        x.set_preference("foo", "bloe")
+
+    def test_get_preference_bool(self):
+        """Check whether a preference can be retrieved."""
+        x = Preferences()
+        x.set_preference("foo", True)
+        self.assertEqual(True, x.get_preference("foo", "bool"))
+
+    def test_get_preference_str(self):
+        """Check whether a string preference can be retrieved."""
+        x = Preferences()
+        x.set_preference("bla", "bloe")
+        self.assertEqual("bloe", x.get_preference("bla"))
+
+    def test_get_preference_nonexistant(self):
+        """Check whether get_preference returns None for nonexisting 
+        options."""
+        x = Preferences()
+        self.assertEqual(None, x.get_preference("foo"))
+

=== renamed file 'olive/ui.py' => 'ui.py'
=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2006-09-06 09:27:12 +0000
+++ viz/branchwin.py	2007-02-03 14:19:20 +0000
@@ -26,13 +26,11 @@
     for a particular branch.
     """
 
-    def __init__(self, app=None):
+    def __init__(self):
         gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
         self.set_border_width(0)
         self.set_title("bzrk")
 
-        self.app = app
-
         # Use three-quarters of the screen by default
         screen = self.get_screen()
         monitor = screen.get_monitor_geometry(0)
@@ -147,112 +145,16 @@
 
     def construct_bottom(self):
         """Construct the bottom half of the window."""
-        scrollwin = gtk.ScrolledWindow()
-        scrollwin.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
-        scrollwin.set_shadow_type(gtk.SHADOW_NONE)
+        from bzrlib.plugins.gtk.logview import LogView
+        self.logview = LogView()
+        self.logview.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+        self.logview.set_shadow_type(gtk.SHADOW_NONE)
         (width, height) = self.get_size()
-        scrollwin.set_size_request(width, int(height / 2.5))
-        scrollwin.show()
-
-        vbox = gtk.VBox(False, spacing=6)
-        vbox.set_border_width(6)
-        scrollwin.add_with_viewport(vbox)
-        vbox.show()
-
-        table = gtk.Table(rows=4, columns=2)
-        table.set_row_spacings(6)
-        table.set_col_spacings(6)
-        vbox.pack_start(table, expand=False, fill=True)
-        table.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        label = gtk.Label()
-        label.set_markup("<b>Revision:</b>")
-        align.add(label)
-        table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
-        label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        self.revid_label = gtk.Label()
-        self.revid_label.set_selectable(True)
-        align.add(self.revid_label)
-        table.attach(align, 1, 2, 0, 1, gtk.EXPAND | gtk.FILL, gtk.FILL)
-        self.revid_label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        label = gtk.Label()
-        label.set_markup("<b>Committer:</b>")
-        align.add(label)
-        table.attach(align, 0, 1, 1, 2, gtk.FILL, gtk.FILL)
-        label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        self.committer_label = gtk.Label()
-        self.committer_label.set_selectable(True)
-        align.add(self.committer_label)
-        table.attach(align, 1, 2, 1, 2, gtk.EXPAND | gtk.FILL, gtk.FILL)
-        self.committer_label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        label = gtk.Label()
-        label.set_markup("<b>Branch nick:</b>")
-        align.add(label)
-        table.attach(align, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
-        label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        self.branchnick_label = gtk.Label()
-        self.branchnick_label.set_selectable(True)
-        align.add(self.branchnick_label)
-        table.attach(align, 1, 2, 2, 3, gtk.EXPAND | gtk.FILL, gtk.FILL)
-        self.branchnick_label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        label = gtk.Label()
-        label.set_markup("<b>Timestamp:</b>")
-        align.add(label)
-        table.attach(align, 0, 1, 3, 4, gtk.FILL, gtk.FILL)
-        label.show()
-        align.show()
-
-        align = gtk.Alignment(0.0, 0.5)
-        self.timestamp_label = gtk.Label()
-        self.timestamp_label.set_selectable(True)
-        align.add(self.timestamp_label)
-        table.attach(align, 1, 2, 3, 4, gtk.EXPAND | gtk.FILL, gtk.FILL)
-        self.timestamp_label.show()
-        align.show()
-
-        self.parents_table = gtk.Table(rows=1, columns=2)
-        self.parents_table.set_row_spacings(3)
-        self.parents_table.set_col_spacings(6)
-        self.parents_table.show()
-        vbox.pack_start(self.parents_table, expand=False, fill=True)
-        self.parents_widgets = []
-
-        label = gtk.Label()
-        label.set_markup("<b>Parents:</b>")
-        align = gtk.Alignment(0.0, 0.5)
-        align.add(label)
-        self.parents_table.attach(align, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
-        label.show()
-        align.show()
-
-        self.message_buffer = gtk.TextBuffer()
-        textview = gtk.TextView(self.message_buffer)
-        textview.set_editable(False)
-        textview.set_wrap_mode(gtk.WRAP_WORD)
-        textview.modify_font(pango.FontDescription("Monospace"))
-        vbox.pack_start(textview, expand=True, fill=True)
-        textview.show()
-
-        return scrollwin
+        self.logview.set_size_request(width, int(height / 2.5))
+        self.logview.show()
+        self.logview.set_show_callback(self._show_clicked_cb)
+        self.logview.set_go_callback(self._go_clicked_cb)
+        return self.logview
 
     def set_branch(self, branch, start, maxnum):
         """Set the branch and start position for this window.
@@ -302,66 +204,7 @@
 
         self.back_button.set_sensitive(len(self.parent_ids[revision]) > 0)
         self.fwd_button.set_sensitive(len(self.children[revision]) > 0)
-
-        if revision.committer is not None:
-            branchnick = ""
-            committer = revision.committer
-            timestamp = format_date(revision.timestamp, revision.timezone)
-            message = revision.message
-            try:
-                branchnick = revision.properties['branch-nick']
-            except KeyError:
-                pass
-
-        else:
-            committer = ""
-            timestamp = ""
-            message = ""
-            branchnick = ""
-
-        self.revid_label.set_text(revision.revision_id)
-        self.branchnick_label.set_text(branchnick)
-
-        self.committer_label.set_text(committer)
-        self.timestamp_label.set_text(timestamp)
-        self.message_buffer.set_text(message)
-
-        for widget in self.parents_widgets:
-            self.parents_table.remove(widget)
-
-        self.parents_widgets = []
-        self.parents_table.resize(max(len(self.parent_ids[revision]), 1), 2)
-        
-        for idx, parent_id in enumerate(self.parent_ids[revision]):
-            align = gtk.Alignment(0.0, 0.0)
-            self.parents_widgets.append(align)
-            self.parents_table.attach(align, 1, 2, idx, idx + 1,
-                                      gtk.EXPAND | gtk.FILL, gtk.FILL)
-            align.show()
-
-            hbox = gtk.HBox(False, spacing=6)
-            align.add(hbox)
-            hbox.show()
-
-            image = gtk.Image()
-            image.set_from_stock(
-                gtk.STOCK_FIND, gtk.ICON_SIZE_SMALL_TOOLBAR)
-            image.show()
-
-            button = gtk.Button()
-            button.add(image)
-            button.set_sensitive(self.app is not None)
-            button.connect("clicked", self._show_clicked_cb,
-                           revision.revision_id, parent_id)
-            hbox.pack_start(button, expand=False, fill=True)
-            button.show()
-
-            button = gtk.Button(parent_id)
-            button.set_use_underline(False)
-            button.connect("clicked", self._go_clicked_cb, parent_id)
-            hbox.pack_start(button, expand=False, fill=True)
-            button.show()
-
+        self.logview.set_revision(revision)
 
     def _back_clicked_cb(self, *args):
         """Callback for when the back button is clicked."""
@@ -396,15 +239,24 @@
             self.treeview.set_cursor(self.index[prev])
         self.treeview.grab_focus()
 
-    def _go_clicked_cb(self, widget, revid):
+    def _go_clicked_cb(self, revid):
         """Callback for when the go button for a parent is clicked."""
         self.treeview.set_cursor(self.index[self.revisions[revid]])
         self.treeview.grab_focus()
 
-    def _show_clicked_cb(self, widget, revid, parentid):
+    def show_diff(self, branch, revid, parentid):
+        """Open a new window to show a diff between the given revisions."""
+        from bzrlib.plugins.gtk.diff import DiffWindow
+        window = DiffWindow()
+        rev_tree = branch.repository.revision_tree(revid)
+        parent_tree = branch.repository.revision_tree(parentid)
+        description = revid + " - " + branch.nick
+        window.set_diff(description, rev_tree, parent_tree)
+        window.show()
+
+    def _show_clicked_cb(self, revid, parentid):
         """Callback for when the show button for a parent is clicked."""
-        if self.app is not None:
-            self.app.show_diff(self.branch, revid, parentid)
+        self.show_diff(self.branch, revid, parentid)
         self.treeview.grab_focus()
 
     def _treeview_row_activated_cb(self, widget, path, col):
@@ -415,6 +267,5 @@
             # Ignore revisions without parent
             return
         parent_id = self.parent_ids[revision][0]
-        if self.app is not None:
-            self.app.show_diff(self.branch, revision.revision_id, parent_id)
+        self.show_diff(self.branch, revision.revision_id, parent_id)
         self.treeview.grab_focus()

=== removed file 'viz/bzrkapp.py'
--- viz/bzrkapp.py	2006-09-06 09:27:12 +0000
+++ viz/bzrkapp.py	1970-01-01 00:00:00 +0000
@@ -1,55 +0,0 @@
-# -*- coding: UTF-8 -*-
-"""Application object.
-
-This module contains the application object that manages the windows
-on screen, and can be used to create new windows of various types.
-"""
-
-__copyright__ = "Copyright © 2005 Canonical Ltd."
-__author__    = "Scott James Remnant <scott@ubuntu.com>"
-
-
-import pygtk
-pygtk.require("2.0")
-
-import gtk
-
-from branchwin import BranchWindow
-from diffwin import DiffWindow
-
-
-class BzrkApp(object):
-    """Application manager.
-
-    This object manages the bzrk application, creating and managing
-    individual branch windows and ensuring the application exits when
-    the last window is closed.
-    """
-
-    def show(self, branch, start, maxnum):
-        """Open a new window to show the given branch."""
-        window = BranchWindow(self)
-        window.set_branch(branch, start, maxnum)
-        window.connect("destroy", self._destroy_cb)
-        window.show()
-
-    def show_diff(self, branch, revid, parentid):
-        """Open a new window to show a diff between the given revisions."""
-        window = DiffWindow()
-        rev_tree = branch.repository.revision_tree(revid)
-        parent_tree = branch.repository.revision_tree(parentid)
-        description = revid + " - " + branch.nick
-        window.set_diff(description, rev_tree, parent_tree)
-        window.show()
-
-    def _destroy_cb(self, widget):
-        """Callback for when a window we manage is destroyed."""
-        self.quit()
-
-    def main(self):
-        """Start the GTK+ main loop."""
-        gtk.main()
-
-    def quit(self):
-        """Stop the GTK+ main loop."""
-        gtk.main_quit()

